pub struct ChannelSendRequestRequest {
pub request: Vec<u8>,
}Fields
request: Vec<u8>Trait Implementations
Sourceimpl Clone for ChannelSendRequestRequest
impl Clone for ChannelSendRequestRequest
Sourcefn clone(&self) -> ChannelSendRequestRequest
fn clone(&self) -> ChannelSendRequestRequest
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for ChannelSendRequestRequest
impl Debug for ChannelSendRequestRequest
Sourceimpl<'a, ___E> Encode<ChannelSendRequestRequest<'static>, ___E> for &'a ChannelSendRequestRequestwhere
___E: InternalHandleEncoder + ?Sized + Encoder,
impl<'a, ___E> Encode<ChannelSendRequestRequest<'static>, ___E> for &'a ChannelSendRequestRequestwhere
___E: InternalHandleEncoder + ?Sized + Encoder,
Sourcefn encode(
self,
encoder_: &mut ___E,
out_: &mut MaybeUninit<ChannelSendRequestRequest<'static>>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder_: &mut ___E, out_: &mut MaybeUninit<ChannelSendRequestRequest<'static>>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
Sourceimpl<___E> Encode<ChannelSendRequestRequest<'static>, ___E> for ChannelSendRequestRequestwhere
___E: InternalHandleEncoder + ?Sized + Encoder,
impl<___E> Encode<ChannelSendRequestRequest<'static>, ___E> for ChannelSendRequestRequestwhere
___E: InternalHandleEncoder + ?Sized + Encoder,
Sourcefn encode(
self,
encoder_: &mut ___E,
out_: &mut MaybeUninit<ChannelSendRequestRequest<'static>>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder_: &mut ___E, out_: &mut MaybeUninit<ChannelSendRequestRequest<'static>>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
Sourceimpl<'a, ___E> EncodeOption<Box<'static, ChannelSendRequestRequest<'static>>, ___E> for &'a ChannelSendRequestRequestwhere
___E: Encoder + ?Sized,
&'a ChannelSendRequestRequest: Encode<ChannelSendRequestRequest<'static>, ___E>,
impl<'a, ___E> EncodeOption<Box<'static, ChannelSendRequestRequest<'static>>, ___E> for &'a ChannelSendRequestRequestwhere
___E: Encoder + ?Sized,
&'a ChannelSendRequestRequest: Encode<ChannelSendRequestRequest<'static>, ___E>,
Sourcefn encode_option(
this: Option<Self>,
encoder: &mut ___E,
out: &mut MaybeUninit<Box<'static, ChannelSendRequestRequest<'static>>>,
_: (),
) -> Result<(), EncodeError>
fn encode_option( this: Option<Self>, encoder: &mut ___E, out: &mut MaybeUninit<Box<'static, ChannelSendRequestRequest<'static>>>, _: (), ) -> Result<(), EncodeError>
Encodes this optional value into an encoder and output.
Sourceimpl<___E> EncodeOption<Box<'static, ChannelSendRequestRequest<'static>>, ___E> for ChannelSendRequestRequestwhere
___E: Encoder + ?Sized,
ChannelSendRequestRequest: Encode<ChannelSendRequestRequest<'static>, ___E>,
impl<___E> EncodeOption<Box<'static, ChannelSendRequestRequest<'static>>, ___E> for ChannelSendRequestRequestwhere
___E: Encoder + ?Sized,
ChannelSendRequestRequest: Encode<ChannelSendRequestRequest<'static>, ___E>,
Sourcefn encode_option(
this: Option<Self>,
encoder: &mut ___E,
out: &mut MaybeUninit<Box<'static, ChannelSendRequestRequest<'static>>>,
_: (),
) -> Result<(), EncodeError>
fn encode_option( this: Option<Self>, encoder: &mut ___E, out: &mut MaybeUninit<Box<'static, ChannelSendRequestRequest<'static>>>, _: (), ) -> Result<(), EncodeError>
Encodes this optional value into an encoder and output.
Sourceimpl<'de> FromWire<ChannelSendRequestRequest<'de>> for ChannelSendRequestRequest
impl<'de> FromWire<ChannelSendRequestRequest<'de>> for ChannelSendRequestRequest
Sourcefn from_wire(wire: ChannelSendRequestRequest<'de>) -> Self
fn from_wire(wire: ChannelSendRequestRequest<'de>) -> Self
Converts the given owned value to this type.
const COPY_OPTIMIZATION: CopyOptimization<W, Self> = _
const COPY_OPTIMIZATION: CopyOptimization<W, Self> = _
Sourceimpl<'de> FromWireRef<ChannelSendRequestRequest<'de>> for ChannelSendRequestRequest
impl<'de> FromWireRef<ChannelSendRequestRequest<'de>> for ChannelSendRequestRequest
Sourcefn from_wire_ref(wire: &ChannelSendRequestRequest<'de>) -> Self
fn from_wire_ref(wire: &ChannelSendRequestRequest<'de>) -> Self
Converts the given reference to this type.
Sourceimpl Hash for ChannelSendRequestRequest
impl Hash for ChannelSendRequestRequest
Sourceimpl Ord for ChannelSendRequestRequest
impl Ord for ChannelSendRequestRequest
Sourcefn cmp(&self, other: &ChannelSendRequestRequest) -> Ordering
fn cmp(&self, other: &ChannelSendRequestRequest) -> Ordering
1.21.0 (const: unstable) · Sourcefn max(self, other: Self) -> Selfwhere
Self: Sized,
fn max(self, other: Self) -> Selfwhere
Self: Sized,
Compares and returns the maximum of two values. Read more
Sourceimpl PartialEq for ChannelSendRequestRequest
impl PartialEq for ChannelSendRequestRequest
Sourcefn eq(&self, other: &ChannelSendRequestRequest) -> bool
fn eq(&self, other: &ChannelSendRequestRequest) -> bool
Tests for
self and other values to be equal, and is used by ==.Sourceimpl PartialOrd for ChannelSendRequestRequest
impl PartialOrd for ChannelSendRequestRequest
impl Eq for ChannelSendRequestRequest
impl StructuralPartialEq for ChannelSendRequestRequest